==> ejc-settlementmanage-impl-3.0.0-20220420.035439-5-sources.jar: com/ejianc/business/settlementmanage/bean/MachinerySettlementEntity.java <==
package com.ejianc.business.settlementmanage.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.settlementmanage.bean.MachinerySettlementDetailEntity;
/**
 * 机械设备结算-主表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_settlementmanage_machinery_settlement")
public class MachinerySettlementEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="contract_id")
    private java.lang.Long contractId; // 合同id
    @TableField(value="contract_name")
    private java.lang.String contractName; // 合同名称
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="org_id")
    private java.lang.Long orgId; // 所属组织id
    @TableField(value="org_name")
    private java.lang.String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private java.lang.Long projectDepartmentId; // 项目部id
    @TableField(value="project_code")
    private java.lang.String projectCode; // 项目编码
    @TableField(value="lessor_name")
    private java.lang.String lessorName; // 租赁商名称
    @TableField(value="settlement_date")
    private java.util.Date settlementDate; // 结算时间
    @TableField(value="billing_start_time")
    private java.util.Date billingStartTime; // 计费起始时间
    @TableField(value="billing_end_time")
    private java.util.Date billingEndTime; // 计费截止时间
    @TableField(value="date")
    private java.util.Date date; // 日期
    @TableField(value="extax_compensation_summary")
    private java.math.BigDecimal extaxCompensationSummary; // 赔偿金额汇总(除税)
    @TableField(value="intax_compensation_summary")
    private java.math.BigDecimal intaxCompensationSummary; // 赔偿金额汇总(含税)
    @TableField(value="extax_monthly_amount")
    private java.math.BigDecimal extaxMonthlyAmount; // 月度结算金额汇总(除税)
    @TableField(value="intax_monthly_amount")
    private java.math.BigDecimal intaxMonthlyAmount; // 月度结算金额汇总(含税)
    @TableField(value="listing_code")
    private java.lang.String listingCode; // 清单编码
    @TableField(value="remarks")
    private java.lang.String remarks; // 备注
    @TableField(value="agent_id")
    private java.lang.Long agentId; // 经办人
    @TableField(value="agent_name")
    private java.lang.String agentName; // 经办人姓名
    @TableField(value="agent_department")
    private java.lang.Long agentDepartment; // 经办人部门
    
    
    @TableField(exist=false)
    @SubEntity(serviceName="machinerySettlementDetailService")
    private List<MachinerySettlementDetailEntity> machinerySettlementDetailEntities = new ArrayList<>(); // 机械设备结算-子表
    

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 合同id
     */
    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 项目编码
     */
    public java.lang.String getProjectCode() {
        return projectCode;
    }

    /**
     * 项目编码
     */
    public void setProjectCode(java.lang.String projectCode) {
        this.projectCode = projectCode;
    }
    /**
     * 租赁商名称
     */
    public java.lang.String getLessorName() {
        return lessorName;
    }

    /**
     * 租赁商名称
     */
    public void setLessorName(java.lang.String lessorName) {
        this.lessorName = lessorName;
    }
    /**
     * 结算时间
     */
    public java.util.Date getSettlementDate() {
        return settlementDate;
    }

    /**
     * 结算时间
     */
    public void setSettlementDate(java.util.Date settlementDate) {
        this.settlementDate = settlementDate;
    }
    /**
     * 计费起始时间
     */
    public java.util.Date getBillingStartTime() {
        return billingStartTime;
    }

    /**
     * 计费起始时间
     */
    public void setBillingStartTime(java.util.Date billingStartTime) {
        this.billingStartTime = billingStartTime;
    }
    /**
     * 计费截止时间
     */
    public java.util.Date getBillingEndTime() {
        return billingEndTime;
    }

    /**
     * 计费截止时间
     */
    public void setBillingEndTime(java.util.Date billingEndTime) {
        this.billingEndTime = billingEndTime;
    }
    /**
     * 日期
     */
    public java.util.Date getDate() {
        return date;
    }

    /**
     * 日期
     */
    public void setDate(java.util.Date date) {
        this.date = date;
    }
    /**
     * 赔偿金额汇总(除税)
     */
    public java.math.BigDecimal getExtaxCompensationSummary() {
        return extaxCompensationSummary;
    }

    /**
     * 赔偿金额汇总(除税)
     */
    public void setExtaxCompensationSummary(java.math.BigDecimal extaxCompensationSummary) {
        this.extaxCompensationSummary = extaxCompensationSummary;
    }
    /**
     * 赔偿金额汇总(含税)
     */
    public java.math.BigDecimal getIntaxCompensationSummary() {
        return intaxCompensationSummary;
    }

    /**
     * 赔偿金额汇总(含税)
     */
    public void setIntaxCompensationSummary(java.math.BigDecimal intaxCompensationSummary) {
        this.intaxCompensationSummary = intaxCompensationSummary;
    }
    /**
     * 月度结算金额汇总(除税)
     */
    public java.math.BigDecimal getExtaxMonthlyAmount() {
        return extaxMonthlyAmount;
    }

    /**
     * 月度结算金额汇总(除税)
     */
    public void setExtaxMonthlyAmount(java.math.BigDecimal extaxMonthlyAmount) {
        this.extaxMonthlyAmount = extaxMonthlyAmount;
    }
    /**
     * 月度结算金额汇总(含税)
     */
    public java.math.BigDecimal getIntaxMonthlyAmount() {
        return intaxMonthlyAmount;
    }

    /**
     * 月度结算金额汇总(含税)
     */
    public void setIntaxMonthlyAmount(java.math.BigDecimal intaxMonthlyAmount) {
        this.intaxMonthlyAmount = intaxMonthlyAmount;
    }
    /**
     * 清单编码
     */
    public java.lang.String getListingCode() {
        return listingCode;
    }

    /**
     * 清单编码
     */
    public void setListingCode(java.lang.String listingCode) {
        this.listingCode = listingCode;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     * 经办人
     */
    public java.lang.Long getAgentId() {
        return agentId;
    }

    /**
     * 经办人
     */
    public void setAgentId(java.lang.Long agentId) {
        this.agentId = agentId;
    }
    /**
     * 经办人姓名
     */
    public java.lang.String getAgentName() {
        return agentName;
    }

    /**
     * 经办人姓名
     */
    public void setAgentName(java.lang.String agentName) {
        this.agentName = agentName;
    }
    
    /**
     * 机械设备结算-子表
     */
    public List<MachinerySettlementDetailEntity> getMachinerySettlementDetailEntities() {
        return machinerySettlementDetailEntities;
    }

    /**
     * 机械设备结算-子表
     */
    public void setMachinerySettlementDetailEntities(List<MachinerySettlementDetailEntity> machinerySettlementDetailEntities) {
        this.machinerySettlementDetailEntities = machinerySettlementDetailEntities;
    }

    public Long getAgentDepartment() {
        return agentDepartment;
    }

    public void setAgentDepartment(Long agentDepartment) {
        this.agentDepartment = agentDepartment;
    }
}

==> ejc-settlementmanage-impl-3.0.0-20220425.073851-9-sources.jar: com/ejianc/business/settlementmanage/bean/MachinerySettlementEntity.java <==
package com.ejianc.business.settlementmanage.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.settlementmanage.bean.MachinerySettlementDetailEntity;
/**
 * 机械设备结算-主表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_settlementmanage_machinery_settlement")
public class MachinerySettlementEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="contract_id")
    private java.lang.Long contractId; // 合同id
    @TableField(value="contract_name")
    private java.lang.String contractName; // 合同名称
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="org_id")
    private java.lang.Long orgId; // 所属组织id
    @TableField(value="org_name")
    private java.lang.String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private java.lang.Long projectDepartmentId; // 项目部id
    @TableField(value="project_code")
    private java.lang.String projectCode; // 项目编码
    @TableField(value="lessor_name")
    private java.lang.String lessorName; // 租赁商名称
    @TableField(value="settlement_date")
    private java.util.Date settlementDate; // 结算时间
    @TableField(value="billing_start_time")
    private java.util.Date billingStartTime; // 计费起始时间
    @TableField(value="billing_end_time")
    private java.util.Date billingEndTime; // 计费截止时间
    @TableField(value="date")
    private java.util.Date date; // 日期
    @TableField(value="extax_compensation_summary")
    private java.math.BigDecimal extaxCompensationSummary; // 赔偿金额汇总(除税)
    @TableField(value="intax_compensation_summary")
    private java.math.BigDecimal intaxCompensationSummary; // 赔偿金额汇总(含税)
    @TableField(value="extax_monthly_amount")
    private java.math.BigDecimal extaxMonthlyAmount; // 月度结算金额汇总(除税)
    @TableField(value="intax_monthly_amount")
    private java.math.BigDecimal intaxMonthlyAmount; // 月度结算金额汇总(含税)
    @TableField(value="listing_code")
    private java.lang.String listingCode; // 清单编码
    @TableField(value="remarks")
    private java.lang.String remarks; // 备注
    @TableField(value="agent_id")
    private java.lang.Long agentId; // 经办人
    @TableField(value="agent_name")
    private java.lang.String agentName; // 经办人姓名
    @TableField(value="agent_department")
    private java.lang.Long agentDepartment; // 经办人部门
    @TableField(exist=false)
    @SubEntity(serviceName="machinerySettlementDetailService", pidName = "mid")/*这个字段属性名千万别动*/
    private List<MachinerySettlementDetailEntity> machinerySettlementDetailEntities = new ArrayList<>(); // 机械设备结算-子表
    

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 合同id
     */
    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 项目编码
     */
    public java.lang.String getProjectCode() {
        return projectCode;
    }

    /**
     * 项目编码
     */
    public void setProjectCode(java.lang.String projectCode) {
        this.projectCode = projectCode;
    }
    /**
     * 租赁商名称
     */
    public java.lang.String getLessorName() {
        return lessorName;
    }

    /**
     * 租赁商名称
     */
    public void setLessorName(java.lang.String lessorName) {
        this.lessorName = lessorName;
    }
    /**
     * 结算时间
     */
    public java.util.Date getSettlementDate() {
        return settlementDate;
    }

    /**
     * 结算时间
     */
    public void setSettlementDate(java.util.Date settlementDate) {
        this.settlementDate = settlementDate;
    }
    /**
     * 计费起始时间
     */
    public java.util.Date getBillingStartTime() {
        return billingStartTime;
    }

    /**
     * 计费起始时间
     */
    public void setBillingStartTime(java.util.Date billingStartTime) {
        this.billingStartTime = billingStartTime;
    }
    /**
     * 计费截止时间
     */
    public java.util.Date getBillingEndTime() {
        return billingEndTime;
    }

    /**
     * 计费截止时间
     */
    public void setBillingEndTime(java.util.Date billingEndTime) {
        this.billingEndTime = billingEndTime;
    }
    /**
     * 日期
     */
    public java.util.Date getDate() {
        return date;
    }

    /**
     * 日期
     */
    public void setDate(java.util.Date date) {
        this.date = date;
    }
    /**
     * 赔偿金额汇总(除税)
     */
    public java.math.BigDecimal getExtaxCompensationSummary() {
        return extaxCompensationSummary;
    }

    /**
     * 赔偿金额汇总(除税)
     */
    public void setExtaxCompensationSummary(java.math.BigDecimal extaxCompensationSummary) {
        this.extaxCompensationSummary = extaxCompensationSummary;
    }
    /**
     * 赔偿金额汇总(含税)
     */
    public java.math.BigDecimal getIntaxCompensationSummary() {
        return intaxCompensationSummary;
    }

    /**
     * 赔偿金额汇总(含税)
     */
    public void setIntaxCompensationSummary(java.math.BigDecimal intaxCompensationSummary) {
        this.intaxCompensationSummary = intaxCompensationSummary;
    }
    /**
     * 月度结算金额汇总(除税)
     */
    public java.math.BigDecimal getExtaxMonthlyAmount() {
        return extaxMonthlyAmount;
    }

    /**
     * 月度结算金额汇总(除税)
     */
    public void setExtaxMonthlyAmount(java.math.BigDecimal extaxMonthlyAmount) {
        this.extaxMonthlyAmount = extaxMonthlyAmount;
    }
    /**
     * 月度结算金额汇总(含税)
     */
    public java.math.BigDecimal getIntaxMonthlyAmount() {
        return intaxMonthlyAmount;
    }

    /**
     * 月度结算金额汇总(含税)
     */
    public void setIntaxMonthlyAmount(java.math.BigDecimal intaxMonthlyAmount) {
        this.intaxMonthlyAmount = intaxMonthlyAmount;
    }
    /**
     * 清单编码
     */
    public java.lang.String getListingCode() {
        return listingCode;
    }

    /**
     * 清单编码
     */
    public void setListingCode(java.lang.String listingCode) {
        this.listingCode = listingCode;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     * 经办人
     */
    public java.lang.Long getAgentId() {
        return agentId;
    }

    /**
     * 经办人
     */
    public void setAgentId(java.lang.Long agentId) {
        this.agentId = agentId;
    }
    /**
     * 经办人姓名
     */
    public java.lang.String getAgentName() {
        return agentName;
    }

    /**
     * 经办人姓名
     */
    public void setAgentName(java.lang.String agentName) {
        this.agentName = agentName;
    }
    
    /**
     * 机械设备结算-子表
     */
    public List<MachinerySettlementDetailEntity> getMachinerySettlementDetailEntities() {
        return machinerySettlementDetailEntities;
    }

    /**
     * 机械设备结算-子表
     */
    public void setMachinerySettlementDetailEntities(List<MachinerySettlementDetailEntity> machinerySettlementDetailEntities) {
        this.machinerySettlementDetailEntities = machinerySettlementDetailEntities;
    }

    public Long getAgentDepartment() {
        return agentDepartment;
    }

    public void setAgentDepartment(Long agentDepartment) {
        this.agentDepartment = agentDepartment;
    }
}
